from pyinspect import install_traceback

install_traceback(relevant_only=True)

from tpd.core import Recorder

recorder = Recorder()
